@@ -352,6 +352,13 @@ void Init_curb_core() {
   rb_define_const(mCurl, "CURLPROXY_SOCKS5", LONG2NUM(-2));
 #endif
 
+  /* When passed to Curl::Easy#proxy_type , indicates that the proxy is a SOCKS5 proxy (and that the proxy should resolve the hostname). (libcurl >= 7.17.2) */
+#ifdef HAVE_CURLPROXY_SOCKS5_HOSTNAME
+  rb_define_const(mCurl, "CURLPROXY_SOCKS5_HOSTNAME", LONG2NUM(CURLPROXY_SOCKS5_HOSTNAME));
+#else
+  rb_define_const(mCurl, "CURLPROXY_SOCKS5_HOSTNAME", LONG2NUM(-2));
+#endif
+
   /* When passed to Curl::Easy#http_auth_types or Curl::Easy#proxy_auth_types, directs libcurl to use Basic authentication. */
 #ifdef HAVE_CURLAUTH_BASIC
   rb_define_const(mCurl, "CURLAUTH_BASIC", LONG2NUM(CURLAUTH_BASIC));
@@ -585,6 +592,9 @@ void Init_curb_core() {
   CURB_DEFINE(CURLOPT_REFERER);
   CURB_DEFINE(CURLOPT_USERAGENT);
   CURB_DEFINE(CURLOPT_HTTPHEADER);
+#if HAVE_CURLOPT_PROXYHEADER
+  CURB_DEFINE(CURLOPT_PROXYHEADER);
+#endif
 #if HAVE_CURLOPT_HTTP200ALIASES
   CURB_DEFINE(CURLOPT_HTTP200ALIASES);
 #endif
@@ -1030,6 +1040,16 @@ void Init_curb_core() {
   CURB_DEFINE(CURLOPT_PIPEWAIT);
 #endif
 
+#if HAVE_CURLOPT_TCP_KEEPALIVE
+  CURB_DEFINE(CURLOPT_TCP_KEEPALIVE);
+  CURB_DEFINE(CURLOPT_TCP_KEEPIDLE);
+  CURB_DEFINE(CURLOPT_TCP_KEEPINTVL);
+#endif
+
+#if HAVE_CURLOPT_HAPROXYPROTOCOL
+  CURB_DEFINE(CURLOPT_HAPROXYPROTOCOL);
+#endif
+
 #if LIBCURL_VERSION_NUM >= 0x072B00 /* 7.43.0 */
   CURB_DEFINE(CURLPIPE_NOTHING);
   CURB_DEFINE(CURLPIPE_HTTP1);
