@@ -59,6 +59,9 @@ def have_constant(name)
   end
 end
 
+have_constant "curlopt_tcp_keepalive"
+have_constant "curlopt_tcp_keepidle"
+have_constant "curlopt_tcp_keepintvl"
 have_constant "curlinfo_appconnect_time"
 have_constant "curlinfo_redirect_time"
 have_constant "curlinfo_response_code"
@@ -84,6 +87,7 @@ have_constant "curlproxy_http"
 have_constant "curlproxy_socks4"
 have_constant "curlproxy_socks4a"
 have_constant "curlproxy_socks5"
+have_constant "curlproxy_socks5_hostname"
 have_constant "curlauth_basic"
 have_constant "curlauth_digest"
 have_constant "curlauth_gssnegotiate"
@@ -152,6 +156,8 @@ have_func("curl_multi_timeout")
 have_func("curl_multi_fdset")
 have_func("curl_multi_perform")
 
+have_constant "curlopt_haproxyprotocol"
+
 # constants
 have_constant "curlopt_interleavefunction"
 have_constant "curlopt_interleavedata"
@@ -216,6 +222,7 @@ have_constant "curlopt_httppost"
 have_constant "curlopt_referer"
 have_constant "curlopt_useragent"
 have_constant "curlopt_httpheader"
+have_constant "curlopt_proxyheader"
 have_constant "curlopt_http200aliases"
 have_constant "curlopt_cookie"
 have_constant "curlopt_cookiefile"
@@ -420,6 +427,8 @@ test_for("curl_easy_escape", "CURL_EASY_ESCAPE", %{
 
 have_func('rb_thread_blocking_region')
 have_header('ruby/thread.h') && have_func('rb_thread_call_without_gvl', 'ruby/thread.h')
+have_header('ruby/io.h')
+have_func('rb_io_stdio_file')
 
 create_header('curb_config.h')
 create_makefile('curb_core')
