@@ -1,3 +1,4 @@
+# frozen_string_literal: true
 module Curl
   class Easy
 
@@ -68,9 +69,14 @@ module Curl
       ret = self.multi.perform
       self.multi.remove self
 
+      if Curl::Multi.autoclose
+        self.multi.close
+        self.multi = nil
+      end
+
       if self.last_result != 0 && self.on_failure.nil?
         error = Curl::Easy.error(self.last_result)
-        raise error.first.new(error.last)
+        raise error.first.new(self.head)
       end
 
       ret
