@@ -6,6 +6,70 @@ class TestCurbCurlMulti < Test::Unit::TestCase
     ObjectSpace.garbage_collect
   end
 
+  # for https://github.com/taf2/curb/issues/277
+  # must connect to an external
+  def test_connection_keepalive
+    # 0123456 default & reserved RubyVM. It will probably include 7 from Dir.glob
+    lsof=`/usr/bin/which lsof`.strip
+    open_fds = lambda do 
+      `#{lsof} -p #{Process.pid} | egrep "TCP|UDP" | wc -l`.strip.to_i
+    end
+    before_open = open_fds.call
+    assert !Curl::Multi.autoclose
+    multi = Curl::Multi.new
+    multi.max_connects = 1 # limit to 1 connection within the multi handle
+
+    did_complete = false
+    5.times do |n|
+      # NOTE: we use google here because connecting to our TEST_URL as a local host address appears to not register correctly with lsof as a socket... if anyone knows a better way would be great to not have an external dependency here in the test
+      easy = Curl::Easy.new("http://google.com/") do |curl|
+        curl.timeout = 5 # ensure we don't hang for ever connecting to an external host
+        curl.on_complete {
+          did_complete = true
+        }
+      end
+      multi.add(easy)
+    end
+
+    multi.perform
+    assert did_complete
+    after_open = open_fds.call
+    assert_equal (after_open - before_open), 1, "with max connections set to 1 at this point the connection to google should still be open"
+    multi.close
+
+    after_open = open_fds.call
+    assert_equal (after_open - before_open), 0, "after closing the multi handle all connections should be closed"
+
+    Curl::Multi.autoclose = true
+    multi = Curl::Multi.new
+    did_complete = false
+    5.times do |n|
+      # NOTE: we use google here because connecting to our TEST_URL as a local host address appears to not register correctly with lsof as a socket... if anyone knows a better way would be great to not have an external dependency here in the test
+      easy = Curl::Easy.new("http://google.com/") do |curl|
+        curl.timeout = 5 # ensure we don't hang for ever connecting to an external host
+        curl.on_complete {
+          did_complete = true
+        }
+      end
+      multi.add(easy)
+    end
+
+    multi.perform
+    assert did_complete
+    after_open = open_fds.call
+    assert_equal (after_open - before_open), 0, "auto close the connections"
+  ensure
+    Curl::Multi.autoclose = false # restore default
+  end
+
+  def test_connection_autoclose
+    assert !Curl::Multi.autoclose
+    Curl::Multi.autoclose = true
+    assert Curl::Multi.autoclose
+  ensure
+    Curl::Multi.autoclose = false # restore default
+  end
+
   def test_new_multi_01
     d1 = ""
     c1 = Curl::Easy.new($TEST_URL) do |curl|
@@ -125,7 +189,7 @@ class TestCurbCurlMulti < Test::Unit::TestCase
   def test_requests
     m = Curl::Multi.new
 
-    assert_equal([], m.requests, 'A new Curl::Multi handle should have no requests')
+    assert_equal(0, m.requests.length, 'A new Curl::Multi handle should have no requests')
 
     10.times do
       m.add(Curl::Easy.new($TEST_URL))
@@ -135,7 +199,7 @@ class TestCurbCurlMulti < Test::Unit::TestCase
 
     m.perform
 
-    assert_equal([], m.requests, 'A new Curl::Multi handle should have no requests after a perform')
+    assert_equal(0, m.requests.length, 'A new Curl::Multi handle should have no requests after a perform')
   end
 
   def test_cancel
@@ -148,7 +212,7 @@ class TestCurbCurlMulti < Test::Unit::TestCase
 
     m.cancel!
 
-    assert_equal([], m.requests, 'A new Curl::Multi handle should have no requests after being canceled')
+    assert_equal(0, m.requests.size, 'A new Curl::Multi handle should have no requests after being canceled')
   end
 
   def test_with_success
@@ -192,7 +256,7 @@ class TestCurbCurlMulti < Test::Unit::TestCase
     c1.on_success do|c|
       success_called1 = true
       #puts "success 1 called: #{c.body_str.inspect}"
-      #assert_match(/^# DO NOT REMOVE THIS COMMENT/, c.body_str)
+      assert_match(/^# DO NOT REMOVE THIS COMMENT/, c.body_str)
     end
 
     c1.on_failure do|c,rc|
@@ -484,5 +548,4 @@ class TestCurbCurlMulti < Test::Unit::TestCase
   def setup
     server_setup
   end
-
 end
